macro_rules! _bail {
($($tokens:tt)*) => { ... };
}Expand description
Returns from the current function with an error, supplied by arguments as for format!
macro_rules! _bail {
($($tokens:tt)*) => { ... };
}Returns from the current function with an error, supplied by arguments as for format!